@@ -6,7 +6,7 @@
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
-# as published by the Free Software Foundation; either version 2
+# as published by the Free Software Foundation; either version 3
 # of the License, or (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
@@ -25,8 +25,10 @@ ScrollArea, that supports kinetic scrolling and other features.
 
 import math
 
-from PyQt5.QtCore import QPoint, QRect, QSize, Qt
-from PyQt5.QtWidgets import QAbstractScrollArea
+# we use util.Point here rather than raw QPoint to prevent an overflow
+# during rapid kinetic scrolling (Frescobaldi issue #2130)
+from PyQt6.QtCore import QRect, QSize, Qt
+from PyQt6.QtWidgets import QAbstractScrollArea
 
 from . import util
 
@@ -34,8 +36,8 @@ from . import util
 class ScrollArea(QAbstractScrollArea):
     """A scroll area that supports kinetic scrolling and other features."""
 
-    #: how to align the scrolled area if smaller than the viewport (Qt.AlignCenter)
-    alignment = Qt.AlignCenter
+    #: how to align the scrolled area if smaller than the viewport (Qt.AlignmentFlag.AlignCenter)
+    alignment = Qt.AlignmentFlag.AlignCenter
 
     #: how many scroll updates to draw per second (50, 50 is recommended).
     scrollupdatespersec = 50
@@ -80,7 +82,7 @@ class ScrollArea(QAbstractScrollArea):
             left = -self.horizontalScrollBar().value()
         if top < 0:
             top = -self.verticalScrollBar().value()
-        return QPoint(left, top)
+        return util.Point(left, top)
 
     def visibleArea(self):
         """Return a rectangle describing the part of the area that is visible."""
@@ -107,7 +109,7 @@ class ScrollArea(QAbstractScrollArea):
             dx = rect.right() - area.right()
         if rect.left() < area.left() + dx:
             dx = rect.left() - area.left()
-        return QPoint(dx, dy)
+        return util.Point(dx, dy)
 
     def ensureVisible(self, rect, margins=None, allowKinetic=True):
         """Performs the minimal scroll to make rect visible.
@@ -152,7 +154,7 @@ class ScrollArea(QAbstractScrollArea):
         """Return the current scroll offset."""
         x = self.horizontalScrollBar().value()
         y = self.verticalScrollBar().value()
-        return QPoint(x, y)
+        return util.Point(x, y)
 
     def canScrollBy(self, diff):
         """Does not scroll, but return the actual distance the View would scroll.
@@ -165,7 +167,7 @@ class ScrollArea(QAbstractScrollArea):
 
         x = min(max(0, hbar.value() + diff.x()), hbar.maximum())
         y = min(max(0, vbar.value() + diff.y()), vbar.maximum())
-        return QPoint(x - hbar.value(), y - vbar.value())
+        return util.Point(x - hbar.value(), y - vbar.value())
 
     def scrollForDragging(self, pos):
         """Slowly scroll the View if pos is close to the edge of the viewport.
@@ -180,7 +182,7 @@ class ScrollArea(QAbstractScrollArea):
         dy = pos.y() - viewport.top() - 12
         if dy >= 0:
             dy = max(0, pos.y() - viewport.bottom() + 12)
-        self.steadyScroll(QPoint(dx*10, dy*10))
+        self.steadyScroll(util.Point(dx*10, dy*10))
 
     def scrollTo(self, pos):
         """Scroll the View to get pos (QPoint) in the top left corner (if possible).
@@ -204,7 +206,7 @@ class ScrollArea(QAbstractScrollArea):
         y = vbar.value()
         vbar.setValue(vbar.value() + diff.y())
         y = vbar.value() - y
-        return QPoint(x, y)
+        return util.Point(x, y)
 
     def kineticScrollTo(self, pos):
         """Scroll the View to get pos (QPoint) in the top left corner (if possible).
@@ -301,9 +303,9 @@ class ScrollArea(QAbstractScrollArea):
 
     def mouseMoveEvent(self, ev):
         """Implemented to handle dragging the document with the left button."""
-        if self.draggingEnabled and ev.buttons() & Qt.LeftButton:
+        if self.draggingEnabled and ev.buttons() & Qt.MouseButton.LeftButton:
             if self._dragPos is None:
-                self.setCursor(Qt.SizeAllCursor)
+                self.setCursor(Qt.CursorShape.SizeAllCursor)
             else:
                 diff = self._dragPos - ev.pos()
                 self._dragSpeed = (ev.timestamp() - self._dragTime, diff)
@@ -314,7 +316,7 @@ class ScrollArea(QAbstractScrollArea):
 
     def mouseReleaseEvent(self, ev):
         """Implemented to handle dragging the document with the left button."""
-        if self.draggingEnabled and ev.button() == Qt.LeftButton and self._dragPos is not None:
+        if self.draggingEnabled and ev.button() == Qt.MouseButton.LeftButton and self._dragPos is not None:
             self.unsetCursor()
             if self.kineticScrollingEnabled and self._dragSpeed is not None:
                 # compute speed of last movement
@@ -328,7 +330,7 @@ class ScrollArea(QAbstractScrollArea):
                 diffy = int(sy * (sy + 1) / 2)
                 if speed.x() < 0: diffx = -diffx
                 if speed.y() < 0: diffy = -diffy
-                self.kineticScrollBy(QPoint(diffx, diffy))
+                self.kineticScrollBy(util.Point(diffx, diffy))
             self._dragPos = None
             self._dragTime = None
             self._dragSpeed = None
@@ -347,24 +349,24 @@ class ScrollArea(QAbstractScrollArea):
         vbar = self.verticalScrollBar()
         # add Home and End, even in non-kinetic mode
         scroll = self.kineticScrollBy if self.kineticScrollingEnabled else self.scrollBy
-        if ev.key() == Qt.Key_Home:
-            scroll(QPoint(0, -vbar.value()))
-        elif ev.key() == Qt.Key_End:
-            scroll(QPoint(0, vbar.maximum() - vbar.value()))
+        if ev.key() == Qt.Key.Key_Home:
+            scroll(util.Point(0, -vbar.value()))
+        elif ev.key() == Qt.Key.Key_End:
+            scroll(util.Point(0, vbar.maximum() - vbar.value()))
         elif self.kineticScrollingEnabled:
             # make arrow keys and PgUp and PgDn kinetic
-            if ev.key() == Qt.Key_PageDown:
-                self.kineticAddDelta(QPoint(0, vbar.pageStep()))
-            elif ev.key() == Qt.Key_PageUp:
-                self.kineticAddDelta(QPoint(0, -vbar.pageStep()))
-            elif ev.key() == Qt.Key_Down:
-                self.kineticAddDelta(QPoint(0, vbar.singleStep()))
-            elif ev.key() == Qt.Key_Up:
-                self.kineticAddDelta(QPoint(0, -vbar.singleStep()))
-            elif ev.key() == Qt.Key_Left:
-                self.kineticAddDelta(QPoint(-hbar.singleStep(), 0))
-            elif ev.key() == Qt.Key_Right:
-                self.kineticAddDelta(QPoint(hbar.singleStep(), 0))
+            if ev.key() == Qt.Key.Key_PageDown:
+                self.kineticAddDelta(util.Point(0, vbar.pageStep()))
+            elif ev.key() == Qt.Key.Key_PageUp:
+                self.kineticAddDelta(util.Point(0, -vbar.pageStep()))
+            elif ev.key() == Qt.Key.Key_Down:
+                self.kineticAddDelta(util.Point(0, vbar.singleStep()))
+            elif ev.key() == Qt.Key.Key_Up:
+                self.kineticAddDelta(util.Point(0, -vbar.singleStep()))
+            elif ev.key() == Qt.Key.Key_Left:
+                self.kineticAddDelta(util.Point(-hbar.singleStep(), 0))
+            elif ev.key() == Qt.Key.Key_Right:
+                self.kineticAddDelta(util.Point(hbar.singleStep(), 0))
             else:
                 super().keyPressEvent(ev)
         else:
@@ -416,7 +418,7 @@ class SteadyScroller(Scroller):
         dy += dy1
 
         # scroll in the right direction
-        diff = QPoint(-dx if x < 0 else dx, -dy if y < 0 else dy)
+        diff = util.Point(-dx if x < 0 else dx, -dy if y < 0 else dy)
         return diff
 
     def finished(self):
@@ -465,7 +467,7 @@ class KineticScroller(Scroller):
         self._x = sx
         self._y = sy
         # the offset is accounted for in the first step
-        self._offset = QPoint(offx, offy)
+        self._offset = util.Point(offx, offy)
 
     def remainingDistance(self):
         """Return the remaining distance."""
@@ -477,7 +479,7 @@ class KineticScroller(Scroller):
         dy = sy * (sy + 1) // 2
         if self._y < 0:
             dy = -dy
-        return QPoint(dx, dy)
+        return util.Point(dx, dy)
 
     def remainingTicks(self):
         """Return the remaining ticks of this scroll."""
@@ -485,7 +487,7 @@ class KineticScroller(Scroller):
 
     def step(self):
         """Return a QPoint indicating the diff to scroll in this step."""
-        ret = QPoint(self._x, self._y)
+        ret = util.Point(self._x, self._y)
         if self._offset:
             ret += self._offset
             self._offset = None
